aboutsummaryrefslogtreecommitdiffstats
path: root/webapp/src/app/@core-xds/services/config.service.ts
diff options
context:
space:
mode:
Diffstat (limited to 'webapp/src/app/@core-xds/services/config.service.ts')
-rw-r--r--webapp/src/app/@core-xds/services/config.service.ts85
1 files changed, 44 insertions, 41 deletions
diff --git a/webapp/src/app/@core-xds/services/config.service.ts b/webapp/src/app/@core-xds/services/config.service.ts
index cc4d237..168b278 100644
--- a/webapp/src/app/@core-xds/services/config.service.ts
+++ b/webapp/src/app/@core-xds/services/config.service.ts
@@ -18,62 +18,65 @@
import { Injectable } from '@angular/core';
import { CookieService } from 'ngx-cookie';
+import { NbThemeService } from '@nebular/theme';
+
import { Observable } from 'rxjs/Observable';
import { BehaviorSubject } from 'rxjs/BehaviorSubject';
-import { AlertService, IAlert } from '../services/alert.service';
-
export interface IConfig {
- language: string;
- projectsRootDir: string;
+ language: string;
+ theme: string;
}
@Injectable()
export class ConfigService {
- public Conf$: Observable<IConfig>;
+ public Conf$: Observable<IConfig>;
- private confSubject: BehaviorSubject<IConfig>;
- private confStore: IConfig;
+ private confSubject: BehaviorSubject<IConfig>;
+ private confStore: IConfig;
- constructor(
- private cookie: CookieService,
- private alert: AlertService,
- ) {
- this.load();
- this.confSubject = <BehaviorSubject<IConfig>>new BehaviorSubject(this.confStore);
- this.Conf$ = this.confSubject.asObservable();
- }
+ constructor(
+ private cookie: CookieService,
+ private themeService: NbThemeService,
+ ) {
+ this.confSubject = <BehaviorSubject<IConfig>>new BehaviorSubject(this.confStore);
+ this.Conf$ = this.confSubject.asObservable();
- // Load config
- load() {
- // Try to retrieve previous config from cookie
- const cookConf = this.cookie.getObject('xds-config');
- if (cookConf != null) {
- this.confStore = <IConfig>cookConf;
- } else {
- // Set default config
- this.confStore = {
- language: 'ENG',
- projectsRootDir: '',
- // projects: []
- };
- }
- }
+ // Load initial config and apply it
+ this.load();
+ this.themeService.changeTheme(this.confStore.theme);
- // Save config into cookie
- save() {
- // Notify subscribers
- this.confSubject.next(Object.assign({}, this.confStore));
+ // Save selected theme in cookie
+ this.themeService.onThemeChange().subscribe(tm => {
+ if (tm.name !== this.confStore.theme) {
+ this.confStore.theme = tm.name;
+ this.save();
+ }
+ });
+ }
- // Don't save projects in cookies (too big!)
- const cfg = Object.assign({}, this.confStore);
- this.cookie.putObject('xds-config', cfg);
+ // Load config
+ load() {
+ // Try to retrieve previous config from cookie
+ const cookConf = this.cookie.getObject('xds-config');
+ if (cookConf != null) {
+ this.confStore = <IConfig>cookConf;
+ } else {
+ // Set default config
+ this.confStore = {
+ language: 'ENG',
+ theme: 'default',
+ };
}
+ }
- set projectsRootDir(p: string) {
- this.confStore.projectsRootDir = p;
- this.save();
- }
+ // Save config into cookie
+ save() {
+ // Notify subscribers
+ this.confSubject.next(Object.assign({}, this.confStore));
+
+ this.cookie.putObject('xds-config', this.confStore);
+ }
}